intelmq.bots.parsers.blocklistde package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.blocklistde package

## Submodules

## intelmq.bots.parsers.blocklistde.parser module

intelmq.bots.parsers.blocklistde.parser.BOT

  alias of `intelmq.bots.parsers.blocklistde.parser.BlockListDEParserBot`

class intelmq.bots.parsers.blocklistde.parser.BlockListDEParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the Blocklist.DE feeds

  parse_line(line, report)

    A generator which can yield one or more messages contained in line.

    Report has the full message, thus you can access some metadata. Override for your use.

## Module contents